import java.awt.*;
import java.io.*;

public class Present extends Frame
{
  int current_slide = 0;
  File slide;
  File story;
  Image background;
  Image bullet;
  Image logo;

  Font h1 = new Font("Helvetica", Font.BOLD | Font.ITALIC, 48);
  Font list = new Font("Helvetica", Font.PLAIN, 32);
  Font body = new Font("Helvetica", Font.PLAIN, 24);

  public Present(File story, int start_slide)
  {
    super("Java Presentation");
    this.story = story;
    current_slide = start_slide;

    MediaTracker tracker = new MediaTracker(this);

    background = Toolkit.getDefaultToolkit().getImage(story.getAbsolutePath() + "/Images/background.gif");
    tracker.addImage(background, 0);

    bullet = Toolkit.getDefaultToolkit().getImage(story.getAbsolutePath() + "/Images/bullet.gif");
    tracker.addImage(bullet, 0);

    logo = Toolkit.getDefaultToolkit().getImage(story.getAbsolutePath() + "/Images/JavaLogo.gif");
    tracker.addImage(logo, 0);

    try {
      tracker.waitForID(0);
    }
    catch (Exception e) {}

    resize(768, 576);
    setResizable(false);
    show();

    slide = new File(story, "Slides/" + current_slide);
  }

  public boolean handleEvent(Event e)
  {
    if (e.id == Event.MOUSE_DOWN)
    {
      if ((e.modifiers & Event.META_MASK) != 0)
      {
        // right button - increment slide
        current_slide++;
      }
      else
      {
        current_slide--;
        if (current_slide < 0)
          current_slide = 0;
      }

      slide = new File(story, "Slides/" + current_slide);
      if (!slide.canRead())
      {
        current_slide = 0;
        slide = new File(story, "Slides/" + current_slide);
      }

      repaint();

      return true;
    }
    else if (e.id == Event.WINDOW_DESTROY)
    {
      System.exit(0);
      return true;
    }

    return false;
  }

  private void parse(Graphics g, File slide)
  {
    try {
      FileInputStream stream = new FileInputStream(slide);
      DataInputStream in = new DataInputStream(stream);
      int y = 0;

      String line = null;

      do {
        line = in.readLine();

        if (line != null)
        {
          if (line.startsWith("#"))
            continue;

          if (line.startsWith("h1"))
          {
            // Heading 1
            y += getFontMetrics(h1).getHeight();
            g.setFont(h1);
            g.setColor(Color.red);
            g.drawString(line.substring(3), 120, y);
          }
          else if (line.startsWith("li"))
          {
            // list item
            int h = getFontMetrics(list).getHeight();
            y += h;
            g.setFont(list);
            g.setColor(Color.black);

            g.drawImage(bullet, 120, y - bullet.getHeight(this), null);

            g.drawString(line.substring(3), 120 + bullet.getWidth(this) + 10, y);
          }
          else if (line.startsWith("l2"))
          {
            // list item
            int h = getFontMetrics(list).getHeight();
            y += h;
            g.setFont(list);
            g.setColor(Color.black);

            g.drawString(line.substring(3), 120 + bullet.getWidth(this) + 10, y);
          }
          else if (line.startsWith("bt"))
          {
            // list item
            int h = getFontMetrics(body).getHeight();
            y += h;
            g.setFont(body);
            g.setColor(Color.black);
            g.drawString(line.substring(3), 200, y);
          }
          else if (line.startsWith("cimg"))
          {
            // centre image
            int h = this.size().height / 3 - logo.getHeight(this) / 2;
            int w = this.size().width / 2 - logo.getWidth(this) / 2;
            g.drawImage(logo, w, h, null);

            y += this.size().height / 3 + logo.getHeight(this) / 2;

          }
          else if (line.startsWith("ch1"))
          {
            // Heading 1
            y += getFontMetrics(h1).getHeight();

            int x = this.size().width / 2 - getFontMetrics(h1).stringWidth(line.substring(4)) / 2;

            g.setFont(h1);
            g.setColor(Color.black);
            g.drawString(line.substring(4), x, y);
          }

        }
      } while (line != null);
    }
    catch (IOException e) { }
  }

  public void repaint(Graphics g)
  {
    update(g);
  }

  public void paint(Graphics g)
  {
    g.drawImage(background, 0, 0, this);

    if (slide != null)
      parse(g, slide);
  }


  public static void main(String args[])
  {
    if ((args.length < 1) || (args.length > 2))
    {
      System.out.println("Present usage: Present Story <slide number>");
      System.exit(1);
    }

    int start_slide = Integer.valueOf(args[1]).intValue();

    File story = new File(args[0]);

    if (!story.isDirectory())
      System.out.println("Not a vaid story");

    new Present(story, start_slide);
  }
}
